
# Transversal parameters ---------------------------------------------------------

n_simulations <- 1000 # Number of simulations considered
Diesel_density <- 0.835
##Through the scripts set.seed() function and seed = 2022 are used in the simulations, in this way, the results can be replicated


# Raw data reading --------------------------------------------------------

## To minimize processing time, code execution is shown for orange and tomato crops, using ReCiPe, USEtox and AWARE midpoint impact categories

db_ecrea <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi1_ECREA.xlsx')) %>%  
  mutate_at(vars(Id_holding_yr,Id_holding,Type_of_crop,Key1,Key2,Key3,Crop,System,Year,NUTS2,NUTS2_ac), as.factor)%>% 
  filter(NUTS2 !='Spain',!is.na(Key1),Count >= 4,Id_holding == 'Fr_Nec_IO_AR') %>% #Crop == 'Tomato'|Crop == 'Orange') %>% 
  mutate(GVA = Gross_incomes+Indemnities-Total_direct_cost-Machine_cost-Capital_insurance_cost-Repairs_and_spare_parts-Conservation_and_improvement_of_buildings_cost-Other_expenses,
         NVA = Gross_incomes+Indemnities-Total_direct_cost-Machine_cost-Capital_insurance_cost-Repairs_and_spare_parts-Conservation_and_improvement_of_buildings_cost-Other_expenses-Amortizations_cost)

db_WS_cf <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi2_subnational_WS.xlsx')) %>% 
  mutate_at(vars(NUTS2),as_factor) 

db_unit_impact <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi3_unit_impact.xlsx')) %>% 
  mutate_at(vars(Id_impact_category,Methodology,Impact_category,Acronym,Level,Time_perspective),as_factor) %>% 
  filter(Methodology == 'ReCiPe_2016_v1.1'|Methodology == 'USE_tox_2.12'|Methodology == 'AWARE_1.2C',
         Acronym != 'CC_excl_bio_C_LUC',Acronym != 'CC_incl_bio_C_LUC',Acronym != 'CC_LUC_only',
         Acronym != 'CC_incl_bio_C',Acronym != 'ET_ri',Acronym != 'HTc_ri',Acronym != 'HTnc_ri',Acronym != 'WS_GA',
         Acronym != 'WS_h',Acronym != 'WS_l',Level == 'Midpoint',Time_perspective == 'H'|Time_perspective == 'G')


db_unit_impact <- db_unit_impact %>% 
  separate(Impact_category,c('Impact_category','Unit'),remove = TRUE, sep = '\\[') %>% 
  mutate(
    temp = '['
  )%>% 
unite(Unit,temp,Unit,remove = T,sep = '')


##   As unit processes are not found for some fertiliser products (Nitrogen solution and NPK products) in the available databases, 
## allocation using the impact results of unit processes DE:NPK15-15-15 (GaBi DB), GLO:market for nitrogen, phosphate and potassium fertiliser, are applied  to estimate their impacts.

Nitrogen_solution <- set_names(c(.32*.5,.32*.5),c('N_as_Urea','N_as_ammonium_nitrate'))
NPK_7_12_7 <- set_names(c(.07,.12,.07),c('N','P2O5','K2O'))
NPK_8_15_15 <- set_names(c(.08,.15,.15),c('N','P2O5','K2O'))
NPK_8_24_8 <- set_names(c(.08,.24,.08),c('N','P2O5','K2O'))
NPK_8_24_16 <- set_names(c(.08,.24,.16),c('N','P2O5','K2O'))
NPK_9_18_27 <- set_names(c(.09,.18,.27),c('N','P2O5','K2O'))
NPK_0_14_7 <- set_names(c(.0,.14,.07),c('N','P2O5','K2O'))
NPK_8_8_8 <- set_names(c(.08,.08,.08),c('N','P2O5','K2O'))
NPK_12_12_24 <- set_names(c(.12,.12,.24),c('N','P2O5','K2O'))
NPK_12_24_8 <- set_names(c(.12,.24,.08),c('N','P2O5','K2O'))

db_unit_impact <- db_unit_impact %>% 
  mutate(
    Nitrogen_solution = ((Nitrogen_solution[1]*Urea)/.46)+((Nitrogen_solution[2]*Ammonium_nitrate)/.335),
  
    NPK_7_12_7 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_7_12_7[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_7_12_7[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_7_12_7[3]*NPK_15_15_15_DE)/.15)),
      
    NPK_8_15_15 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_15_15[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_15_15[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_15_15[3]*NPK_15_15_15_DE)/.15)),
      
    NPK_8_24_8 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_8[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_8[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_8[3]*NPK_15_15_15_DE)/.15)),
      
    NPK_8_24_16 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_16[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_16[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_24_16[3]*NPK_15_15_15_DE)/.15)),
    
    NPK_9_18_27 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_9_18_27[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_9_18_27[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_9_18_27[3]*NPK_15_15_15_DE)/.15)),
    
    NPK_0_14_7 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_0_14_7[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_0_14_7[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_0_14_7[3]*NPK_15_15_15_DE)/.15)),
    
    NPK_12_12_24 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_12_24[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_12_24[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_12_24[3]*NPK_15_15_15_DE)/.15)),
    
    NPK_12_24_8 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_24_8[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_24_8[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_12_24_8[3]*NPK_15_15_15_DE)/.15)),
    
    NPK_8_8_8 = ((N_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_8_8[1]*NPK_15_15_15_DE)/.15))+
      ((P2O5_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_8_8[2]*NPK_15_15_15_DE)/.15))+
      ((K2O_fertiliser/(N_fertiliser+P2O5_fertiliser+K2O_fertiliser))*((NPK_8_8_8[3]*NPK_15_15_15_DE)/.15))
  )
 

db_unit_impact <- db_unit_impact %>% 
  gather(Ammonium_nitrate_DE,Ammonium_nitrate,Ammonium_sulfate,
         Calcium_ammonium_nitrate,Diammonium_phosphate,Potassium_sulfate,Single_superphosphate,Urea,Nitrogen_solution,
         N_fertiliser,P2O5_fertiliser,K2O_fertiliser,NPK_15_15_15_DE,NPK_0_14_7,NPK_12_12_24,NPK_12_24_8,
         NPK_7_12_7,NPK_8_15_15,NPK_8_24_16,NPK_8_24_8,NPK_8_8_8,NPK_9_18_27,#fertilizantes
         Machinery_use,Diesel,Diesel_on_field,Electricity,NH3,N2O,NO3_,
         NOx,PO43_,#On-field emissions and other elements
         Fungicide_DE,Herbicide_DE,Insecticide_Carb_1_DE,Insecticide_Carb_2_DE,Insecticide_Pyrethroid_DE,
         Plant_growth_regulator_DE,Seed_treatment_DE,Ammonium_thiocyanate.production,Copper_sulfate,
         GLO_Pesticide_average,GLO_phosphane_production_ecoinvent_3.5,Wood_preservative_1,Wood_preservative_2,
         Wood_preservative_3,Wood_preservative_4,Wood_preservative_5,Wood_preservative_6,Wood_preservative_7,
         Wood_preservative_8,Wood_preservative_RER,Sulfonyl_urea_compound,D2_4_dichlorophenol,
         Acetamide_anillide_compound,Aclonifen,Atrazine,Benzimidazole_compound,Benzo_thia_diazole_compound,
         Benzoic_compound,Bipyridylium_compound,Chlorothalonil,Copper_oxide,Cyclic_N_compound,Diazine_compound,
         Dimethenamide,Dinitroaniline_compound,Diphenylether_compound,Dithiocarbamate_compound,Folpet,
         Fosetyl_Al,Glyphosate,Isoproturon,Mancozeb,Mecoprop,Metaldehyde,Metamitron,Napropamide,Nitrile_compound,
         Nitro_compound,Orbencarb,Organophosphorus_compound,Pendimethalin,Phthalimide_compound,Pesticide_RER,Phenoxy_compound,
         Prosulfocarb,Pyridazine_compound,Pyridine_compound,Fatty_alcohol_ethoxylate,Secondary_sulphur_at_refinery,Sodium_nitrite,
         Triazine_compound,Captan,#pesticides
         HDPE_extrusion_film,LDPE_extrusion_film,PC_extrusion_film,PE_blow_molding,PE_injection_molding,
         PP_extrusion_film,PVC_extrusion_film,Polyethylene_Film_HDPE_without_additives_DE,
         Polyethylene_Film_LDPE_without_additives_DE,Polypropylene_Film_PP_without_additives_DE,
         Steel_electrogalvanized,Steel_hot_dip_galvanised,
         Lorry_22t_incl_fuel,Polyethylene_film_LDPE,Polyethylene_pipe_HDPE,Polypropylene_film_PP,
         Polypropylene_injection_moulding_part_PP,Polystyrene_production_expandable,Polyvinyl_chloride_film_PVC,
         Polyvinylchloride_injection_moulding_part_PVC,Polyvinylchloride_pipe_PVC,Zinc_coating_pieces,Steel_drawing_of_pipe,Concrete_foundation,
         Extrusion_plastic_pipe,#Greenhouse structure
         Diesel_pump,Electric_pump,#Maquina para irrigación
         key = 'Process', value = 'Unit_impact')# %>%  
  #mutate(llave = 'unitario')


## Comprehensive data frame of the unit impacts from the unit process plus WS charaterisation factors is created

db_WS_cf1 <- db_WS_cf %>% 
  rename(Process = NUTS2,
         Unit_impact = WS_cf) %>% 
  mutate(Id_impact_category = db_unit_impact$Id_impact_category[28],
         Methodology = db_unit_impact$Methodology[28],
         Impact_category = db_unit_impact$Impact_category[28],
        Acronym = db_unit_impact$Acronym[28],
          Level = db_unit_impact$Level[28],
          Time_perspective = db_unit_impact$Time_perspective[28],
          Unit = db_unit_impact$Unit[28])


db_unit_impact <- db_unit_impact %>% 
  full_join(db_WS_cf1)

db_unit_impact1 <- db_unit_impact %>% 
  dplyr::select(Methodology,Impact_category,Acronym,Unit,Time_perspective,Process,Unit_impact)

db_unit_impact2 <- db_unit_impact %>% 
  filter(Process == 'Urea') %>% 
  dplyr::select(Id_impact_category,Methodology,Impact_category,Acronym,Unit,Time_perspective)


Id_impact_category_l <- levels(db_unit_impact$Id_impact_category)
Methodology_l <- levels(db_unit_impact$Methodology)
Category_l <- levels(db_unit_impact$Impact_category)
Acronym_l <- levels(db_unit_impact$Acronym)
Unit_l <- levels(db_unit_impact$Unit)
Time_perspective_l <- levels(db_unit_impact$Time_perspective)

