

# Raw data reading ---------------------------------------------------------------


db_infra1 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi4_input_infrastructure.xlsx'))%>% 
  filter(Type_of_structure2 != 'Multi_tunnel2') %>% 
  dplyr::select(Type_of_structure2,Item,Process,Consumption,RSD) %>% 
  mutate_at(vars(Type_of_structure2,Item,Process),as_factor)

# Estimation of the material consumption from greenhouse structure and irrigation system  ----------------------------------------------------------------
## 'Parral' greenhouse structure is considered in Andalucia, Multi-tunnel1 grenhouse for the other NUTS 2 

db_infra_temp <- db_ecrea %>%
  dplyr::select(Id_holding_yr,Id_holding,Type_of_crop,(Crop:Yield)) %>% 
  filter(System != 'Rainfed open field')%>% 
  mutate(Type_of_structure2 =  ifelse(System == 'Irrigated greenhouse' & NUTS2_ac == 'AN','Parral',
                                   ifelse(System == 'Irrigated greenhouse' & NUTS2_ac != 'AN','Multi_tunnel1',
                                          'Open field')
                                   )) %>% 
  mutate_at(vars(Type_of_structure2),as_factor)
                                   
 
db_infra1 <- db_infra_temp %>% 
  left_join(db_infra1) %>% 
  mutate(Sd = Consumption*RSD,
         ll = ifelse(Consumption-(Consumption*RSD*3) < 0,0,Consumption-(Consumption*RSD*3)),
         ul = Consumption+(Consumption*RSD*1))

set.seed(2022)

db_infra2 <- map_df(.x = 1:nrow(db_infra1),.f = function(x){
  db_infra2 <- tibble(Id_sample = c(1:n_simulations),
                                  Id_holding_yr = db_infra1$Id_holding_yr[x],
                                  Id_holding = db_infra1$Id_holding[x],
                                  Type_of_crop = db_infra1$Type_of_crop[x],
                                  Crop = db_infra1$Crop[x],
                                  System = db_infra1$System[x],
                                  NUTS2 = db_infra1$NUTS2[x],
                                  Year = db_infra1$Year[x],
                                  Item = db_infra1$Item[x],
                                  Process = db_infra1$Process[x],
                                  Consumption = rtriangle(n = n_simulations,a = db_infra1$ll[x],
                                                          b = db_infra1$ul[x],c = db_infra1$Consumption[x])/db_infra1$Yield[x])
  
  db_infra2
})


db_infra3 <- db_infra2 %>% 
  group_by(Id_sample,Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year,Process) %>% 
  summarise(Consumption = sum(Consumption))


# Impacts from infrastructure ---------------------------------------------
## unit process impacts data frame is linked to db_infra3, and impacts from infrastructure are estimated

i_infra1 <- db_infra3 %>% 
  left_join(db_unit_impact1) %>% 
  mutate(Impact = Consumption*Unit_impact) %>% 
  group_by(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Unit) %>% 
  summarise(Impact = sum(Impact))


## The following line can be used to save the impacts estimated from infrastructure stage as feather file
#write_feather(i_infra1,'iar_infra_EF_f')

