# Raw data reading --------------------------------------------------------

db_fer1 <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi5_fertiliser_product.xlsx')) %>% 
  mutate_at(vars(Year, Fertiliser_product),as_factor) %>% 
  right_join(db_ecrea)

# Modeling  ----------------------------------------------------------------
## Linear programming to estimate fertiliser consumption

id_i <- db_ecrea$Id_holding_yr
nuts2_i <- levels(db_ecrea$NUTS2_ac)
year_i <- levels(db_ecrea$Year)
crop_i <- levels(db_ecrea$Crop)
system_i <- levels(db_ecrea$System)
fer_list <- levels(db_fer1$Fertiliser_product)

dir <- c('>=','>=','>=','<=')


  db_con <- NULL
  db_basvar <- NULL
  db_opt <- NULL
  db_solution <- NULL
  solution_con <- NULL
  solution_basvar <- NULL
  solution_opt <- NULL
  solution_sol <- NULL
  solution_con <- NULL
  matrix_ac <- NULL 
  fun_obj_ac <- NULL
  vector_b_ac <- NULL
  db_basvar <- NULL


model_fer <- for (i in id_i){
  Id <- print(i)
  
  ## Inputs
  
  fun_obj <- db_fer1%>%filter(Id_holding_yr==i)%>%dplyr::select(Fertiliser_product,cost_kg);
  fun_obj <- set_names(c(fun_obj$cost_kg),fun_obj$Fertiliser_product);
  
  matrixI <- db_fer1%>%
    filter(Id_holding_yr==i)%>%
    dplyr::select(Fertiliser_product,N_content,P2O5_content,K2O_content,cost_kg);
  fun_obj_ac <- list(fun_obj_ac,fun_obj);
  matrixA <- matrix(c(matrixI$N_content,matrixI$P2O5_content,matrixI$K2O_content,matrixI$cost_kg),ncol=4);
  colnames(matrixA) <- c('Nitrogen','P2O5','K2O','Fertiliser_cost');
  rownames(matrixA) <- matrixI$Fertiliser_product;
  matrixA <- t(matrixA);

  vector_b<- db_ecrea%>%
    filter(Id_holding_yr==i)%>%
    dplyr::select(Nitrogen_supplied,P2O5_supplied,K2O_supplied, Fertiliser_cost);
  vector_b <- c(vector_b$Nitrogen_supplied,vector_b$P2O5_supplied,vector_b$K2O_supplied,vector_b$Fertiliser_cost);
  vector_b <- set_names(vector_b,c('Nitrogen','P2O5','K2O','Fertiliser_cost'));

  ## Outputs
  solution_basvar1 <- solveLP(fun_obj,vector_b,matrixA,maximum = FALSE,dir)$basvar;
  solution_basvar <- tibble(Id_holding_yr=Id,Solution=row.names(solution_basvar1),Opt.consumption=solution_basvar1);
  db_basvar <- rbind(db_basvar,solution_basvar)
} 



db_fer2 <- db_basvar %>% 
  transmute(
    Id_holding_yr = Id_holding_yr,
    Fertiliser_product = Solution,
    Opt.consumption = Opt.consumption
  ) %>% 
  left_join(db_fer1) %>% 
  filter(!is.na(Opt.consumption),!is.na(Type_of_fertiliser)) %>% 
  mutate(Consumption = Opt.consumption/Yield) 

db_fer3 <- db_fer2%>% 
  dplyr::select(Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year,Fertiliser_product,Consumption)

# Impacts from fertiliser production ---------------------------------------
## unit process impacts data frame is linked to db_fer3, and impacts from fertiliser production are estimated

i_fer1 <- db_fer3 %>% 
  rename(Process = Fertiliser_product) %>% 
  left_join(db_unit_impact1) %>% 
  mutate(Impact= Consumption*Unit_impact) %>% 
  group_by(Id_holding_yr,Methodology,Impact_category,Acronym,Time_perspective,Unit) %>% 
  summarise(Impact = sum(Impact))

i_fer2 <- map_df(.x = 1:nrow(i_fer1),.f = function(x){
  
  i_fer2 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = i_fer1$Id_holding_yr[x],
    Methodology = i_fer1$Methodology[x],
    Impact_category = i_fer1$Impact_category[x],
    Acronym = i_fer1$Acronym[x],
    Unit = i_fer1$Unit[x],
    Impact = i_fer1$Impact[x]
  )
  
  i_fer2
})

## The following line can be used to save the impacts estimated from fertiliser production stage as feather file
#write_feather(i_fer2,'iar_fer_pd_EF_f')

