# Raw data reading --------------------------------------------------------

db_pest1 <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi6_pest_dose.xlsx')) %>% 
  mutate_at(vars(Key1,Active_substance,Impact_process,USEtox_name),as_factor)

# Data tidying and linking dose of pesticides with the reference holdings -----------------------------------------------------
## only the 75% of the most used active substance are considered


db_pest2 <- db_pest1 %>% 
  group_by(Key1) %>% 
  mutate(Dummy_temp = ifelse(Basic_surface>= 0.25*max(Basic_surface),1,0)) %>% 
  filter(Dummy_temp == 1) %>% 
  right_join(dplyr::select(db_ecrea,Id_holding_yr,Type_of_crop,Id_holding,Key1,Key2,Key3,Crop,System,NUTS2,Year,Yield)) %>% 
  mutate(Consumption = Dose_basic_surface/Yield)


db_pest3 <- db_pest2 %>% 
  dplyr::select(Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year,Active_substance,Impact_process,Consumption) %>% 
  rename(Process = Impact_process)


# Impacts from pesticide production ---------------------------------------
## unit process impacts data frame is linked to db_pest3, and impacts from pesticide production are estimated

i_pest1 <- db_pest3 %>% 
  left_join(db_unit_impact1) %>% 
  mutate(Impact = Consumption*Unit_impact) %>% 
  group_by(Id_holding_yr,Methodology,Impact_category,Acronym,Time_perspective, Unit) %>% 
  summarise(Impact = sum(Impact))


i_pest2 <- map_df(.x = 1:nrow(i_pest1),.f = function(x){
  
  i_pest2 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = i_pest1$Id_holding_yr[x],
    Methodology = i_pest1$Methodology[x],
    Impact_category = i_pest1$Impact_category[x],
    Acronym = i_pest1$Acronym[x],
    Unit = i_pest1$Unit[x],
    Impact = i_pest1$Impact[x]
  )
  
  i_pest2
})


## The following line can be used to save the impacts estimated from pesticide production stage as feather file 
#write_feather(i_pest2,'iar_pest_pd_EF_f')


