
# Raw data reading ---------------------------------------------------------------

##  Input files to estimate fertiliser on-field emissions

db_fer_e1 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi7_fertiliser_ef.xlsx'))%>% 
  mutate_at(vars(Type_of_fertiliser,Weather,Type_of_PH,Type_emission),as.factor)

db_fer_e2 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi8_n_and_p_balances1.xlsx'))%>% 
  mutate_at(vars(Key2,NUTS2,Year),as.factor)

db_fer_e3 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi9_n_and_p_balances2.xlsx'))%>% 
  mutate_at(vars(Year),as.factor) %>% 
  dplyr::select(-(Region))

## Input files to estimate pesticide on-field emissions

db_pest_e1 <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi10_pestl_consensus_sim.xlsx')) %>% 
  mutate_at(vars(Key3),as_factor) %>% 
  filter(FI!=0)# Scenario without drift reduction (FI) is not considered

db_pest_e2 <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi11_land_surface.xlsx')) %>% 
  mutate_at(vars(NUTS2,Year),as_factor)

db_pest_e3 <- read.xlsx(xlsxFile=file.path(InputData_path,'Dbi12_pest_CF_recipe.xlsx'))


# On-field Emissions from fertilisers --------------------------------------------------------------

## Data is tidied to estimate HN3 emissions 

db_fer_e1 <- db_fer_e1 %>% 
 dplyr:: transmute(
    Type_of_fertiliser = Type_of_fertiliser,
    Weather = Weather,
    Type_of_PH = Type_of_PH,
    Type_emission = Type_emission,
    Recommended_value = Recommended_value,
    Mean = ifelse(is.na(Mean),Recommended_value,Mean),
    sample_size = sample,
    Li_mean = Li_mean,
    Ls_mean = Ls_mean,
    Standard_error = ifelse(is.na(Standard_error),(Ls_mean-Li_mean)/(2*1.96),Standard_error), # this data is just informative, it is estimated considering a CI on 95%
    Sd = Standard_error*sqrt(sample),
    IC = IC,
    Reference = Reference
  )



db_fer_e4 <- db_fer_e1 %>% 
  filter(Type_emission == 'NH3',Weather == 'Temperate',Type_of_PH == 'high_pH') %>% #
  right_join(db_fer2) %>% 
  dplyr::select(Id_holding_yr,Type_of_crop,Id_holding,Key1,Key2,Key3,NUTS2,Crop,System,Year,Type_of_fertiliser,Li_mean,Ls_mean,Recommended_value, Consumption, N_content,P_content,Yield) 


set.seed(2022)

db_fer_e5 <- map_df(.x = 1:nrow(db_fer_e4),.f = function (x){
  
  db_fer_e5 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = db_fer_e4$Id_holding_yr[x],
    Type_of_crop = db_fer_e4$Type_of_crop[x],
    Id_holding = db_fer_e4$Id_holding[x],
    Key1 = db_fer_e4$Key1[x],
    Key2 = db_fer_e4$Key2[x],
    Key3 = db_fer_e4$Key3[x],
    Crop = db_fer_e4$Crop[x],
    System = db_fer_e4$System[x],
    NUTS2 = db_fer_e4$NUTS2[x],
    Year = db_fer_e4$Year[x],
    Type_of_fertiliser = db_fer_e4$Type_of_fertiliser[x],
    Nitrogen = db_fer_e4$Consumption[x]*db_fer_e4$N_content[x],
    Phosphorus = db_fer_e4$Consumption[x]*db_fer_e4$P_content[x],
    NH3 = Nitrogen*rtriangle(n = n_simulations,a = db_fer_e4$Li_mean[x],b = db_fer_e4$Ls_mean[x],c = db_fer_e4$Recommended_value[x])
  )
  
  db_fer_e5
})


db_fer_e6 <-  db_fer_e5 %>% 
  group_by(Id_sample,Id_holding_yr,Type_of_crop,Id_holding,Key1,Key2,Key3,Crop,System,NUTS2,Year) %>% 
  summarise(Nitrogen = sum(Nitrogen, na.rm = T),
            Phosphorus = sum(Phosphorus, na.rm =T),
            NH3 = sum(NH3, na.rm = T))


## Data are tidied to estimate and linK nitrogen and phosphorus balances to the reference holdings

N_input_pivot <- db_fer_e3$N_input_pt[7]
N_balance_pivot <- db_fer_e3$N_balance_pt[7]
P_input_pivot <- db_fer_e3$P_input_pt[7]
P_balance_pivot <- db_fer_e3$P_balance_pt[7]

db_fer_e2 <- db_fer_e2 %>% 
  right_join(db_fer_e3) %>% 
  group_by(Key2,NUTS2) %>%
  mutate(N_input = ifelse(Year == '2016',N_input16,(mean(N_input16,na.rm = T)*N_input_pt)/N_input_pivot),
         N_balance = ifelse(Year == '2016',N_balance16,(mean(N_balance16,na.rm = T)*N_balance_pt)/N_balance_pivot),
         P_input = ifelse(Year == '2016',P_input16,(mean(P_input16,na.rm = T)*P_input_pt)/P_input_pivot),
         P_balance = ifelse(Year == '2016',P_balance16,(mean(P_balance16,na.rm = T)*P_balance_pt)/P_balance_pivot))


db_fer_e2 <- db_fer_e2 %>% 
  mutate(
    porc_lix_n = ifelse(N_balance > 0,N_balance/N_input,0),##  Nitrogen and Phosphorus balances are taking into account to establish the potential leaching fraction 
    porc_lix_p = ifelse(P_balance > 0,P_balance/P_input,0)
  ) %>% 
  dplyr::select(Key2,NUTS2,Year,porc_lix_n,porc_lix_p)

  
# Leaching fractions are joined with  NH3 emissions
db_fer_e7 <-  db_fer_e6 %>% 
  left_join(db_fer_e2)


# NOx and N2O emissions are estimated -----------------------------------------------------

NOx_ef <- c(db_fer_e1$Li_mean[67],db_fer_e1$Ls_mean[67],db_fer_e1$Recommended_value[67])
N2O_d_rainfed_ef <- c(db_fer_e1$Li_mean[69],db_fer_e1$Ls_mean[69],db_fer_e1$Recommended_value[69])
N2O_d_irrigated_ef <- c(db_fer_e1$Li_mean[68],db_fer_e1$Ls_mean[68],db_fer_e1$Recommended_value[68])
N2O_n_leach_ef <- c(db_fer_e1$Li_mean[74],db_fer_e1$Ls_mean[74],db_fer_e1$Recommended_value[74])
N2O_n_vol_ef <- c(db_fer_e1$Li_mean[73],db_fer_e1$Ls_mean[73],db_fer_e1$Recommended_value[73])

set.seed(2022)

db_fer_e8 <- map_df(.x = 1:nrow(db_ecrea),.f = function (x){
  
  db_fer_e8 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = db_ecrea$Id_holding_yr[x],
    Type_of_crop = db_ecrea$Type_of_crop[x],
    Id_holding =db_ecrea$Id_holding[x],
    Crop = db_ecrea$Crop[x],
    System = db_ecrea$System[x],
    Year = db_ecrea$Year[x],
    NOx_ef = rtriangle(n_simulations,NOx_ef[1],NOx_ef[2],NOx_ef[3]),
    N2O_d_rainfed_ef = rtriangle(n_simulations,N2O_d_rainfed_ef[1],N2O_d_rainfed_ef[2],N2O_d_rainfed_ef[3]),
    N2O_d_irrigated_ef = rtriangle(n_simulations,N2O_d_irrigated_ef[1],N2O_d_irrigated_ef[2],N2O_d_irrigated_ef[3]),
    N2O_n_leach_ef = rtriangle(n_simulations,N2O_n_leach_ef[1],N2O_n_leach_ef[2],N2O_n_leach_ef[3]),
    N2O_n_vol_ef = rtriangle(n_simulations,N2O_n_vol_ef[1],N2O_n_vol_ef[2],N2O_n_vol_ef[3])
  )
  db_fer_e8
})

## Molecular mass of fertiliser emissions
H_mw <- 1
N_mw <- 14
O_mw <- 16
P_mw <- 31
NH3_mw <- N_mw + (H_mw*3)
NOx_mw <- N_mw+(O_mw*2)
N2O_mw <- (N_mw*2)+O_mw
NO3_mw <- (O_mw*3)+N_mw
PO43_mw <- (O_mw*4)+P_mw

db_fer_e9 <- db_fer_e7 %>% 
  inner_join(db_fer_e8)



db_fer_e9 <- db_fer_e9 %>% 
  mutate(
    NOx = (Nitrogen-(NH3*(N_mw/NH3_mw)))*NOx_ef,
    NO3_ = (Nitrogen*porc_lix_n)*(NO3_mw/N_mw),
    N2O  = ((ifelse(System == 'Rainfed open field',N2O_d_rainfed_ef,N2O_d_irrigated_ef)*(Nitrogen-(NH3*(N_mw/NH3_mw))-
                                                                                ((Nitrogen-(NH3*(N_mw/NH3_mw)))*NOx_ef*(N_mw/NOx_mw)))                                                                 
    )+
      (((NH3*(N_mw/NH3_mw))+((Nitrogen-(NH3*(N_mw/NH3_mw)))*NOx_ef*(N_mw/NOx_mw)))*N2O_n_vol_ef) +
      (Nitrogen*porc_lix_n*N2O_n_leach_ef))*(N2O_mw/(N_mw*2)),
    
    PO43_ = (Phosphorus*porc_lix_p)*(PO43_mw/P_mw)       
  )


db_fer_e10 <- tibble(Id_sample = db_fer_e9$Id_sample,
                          Id_holding_yr = db_fer_e9$Id_holding_yr,
                          Type_of_crop = db_fer_e9$Type_of_crop,
                          Id_holding = db_fer_e9$Id_holding,
                          Crop = db_fer_e9$Crop,
                          System = db_fer_e9$System,
                          NUTS2 = db_fer_e9$NUTS2,
                          Year = db_fer_e9$Year,
                          NH3 = db_fer_e9$NH3,
                          NOx = db_fer_e9$NOx,
                          NO3_ = db_fer_e9$NO3_,
                          N2O = db_fer_e9$N2O,
                          PO43_ = db_fer_e9$PO43_
)



# Impacts from fertiliser emissions ----------------------------------------------------
## unit process impacts data frame is linked to db_fer_e10 to estimate the impacts from fertiliser emissions

db_fer_e11 <- db_fer_e10 %>% 
  gather(NH3,NOx,NO3_,N2O,PO43_,key = 'Process',value = 'Emissions')


i_onfield1 <- db_fer_e11 %>% 
  left_join(db_unit_impact1)

i_onfield1 <- i_onfield1 %>% 
  mutate(Impact = Emissions*Unit_impact)

i_onfield1 <- i_onfield1 %>% 
  group_by(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Unit) %>% 
  summarise(Impact = sum(Impact)) 
  
i_onfield1 <- i_onfield1 %>%  
  filter(Impact != 0)

# On-field pesticide emissions -----------------------------------------------------
## Data is tidied to estimate HN3 emissions

db_pest_e1 <- db_pest_e1 %>%
  dplyr::select(Key3,(c_PrimAir:c_PrimOffField)) %>% 
  right_join(dplyr::select(db_ecrea,Id_holding_yr,Id_holding,Crop,Key3,System,NUTS2,Year)) %>% 
  mutate(Id_pest_f = paste(Id_holding_yr,Key3,sep = '_'))



## Following personal recommendation, for greenhouse system, 0.05% of the pesticide active substance applied is emitted to air and off-field compartments 

db_pest_e1$c_PrimAir <- ifelse(db_pest_e1$System == 'Irrigated greenhouse',.0005*(db_pest_e1$c_PrimAir/(db_pest_e1$c_PrimAir+db_pest_e1$c_PrimOffField)),
                               db_pest_e1$c_PrimAir)

db_pest_e1$c_PrimOffField <- ifelse(db_pest_e1$System == 'Irrigated greenhouse',(.0005-db_pest_e1$c_PrimAir),
                                    db_pest_e1$c_PrimOffField)  

db_pest_e1$c_PrimSoil <- ifelse(db_pest_e1$System == 'Irrigated greenhouse',(1-.0005)*(db_pest_e1$c_PrimSoil/(db_pest_e1$c_PrimSoil+db_pest_e1$c_PrimCrop)),
                                db_pest_e1$c_PrimSoil) 

db_pest_e1$c_PrimCrop <- ifelse(db_pest_e1$System == 'Irrigated greenhouse',(1-.0005)-db_pest_e1$c_PrimSoil,
                                db_pest_e1$c_PrimCrop)  


## To have the simulations of the primary pesticide distribution, a resampling is applied

pest_e_temp <- distinct(tibble (db_pest_e1$Id_holding_yr))

db_pest_e5 <- map_df(.x = pest_e_temp$`db_pest_e1$Id_holding_yr`,.f = function(x){
  
  set.seed(2022)
  
  db_pest_e4 <- db_pest_e1 %>% 
    filter(Id_holding_yr == str_c('',x)) 
  
  db_pest_e5 <- tibble(n_origin_sample = sample(1:length(db_pest_e4$Id_holding_yr),n_simulations,replace = T),
                                  Id_sample = c(1:n_simulations),
                                  Id_holding_yr = db_pest_e4$Id_holding_yr[n_origin_sample],
                                  Type_of_crop = db_pest_e4$Type_of_crop[n_origin_sample],
                                  Id_holding = db_pest_e4$Id_holding[n_origin_sample],
                                  Crop = db_pest_e4$Crop[n_origin_sample],
                                  System = db_pest_e4$System[n_origin_sample],
                                  NUTS2 = db_pest_e4$NUTS2[n_origin_sample],
                                  Year = db_pest_e4$Year[n_origin_sample],
                                  c_PrimAir = db_pest_e4$c_PrimAir[n_origin_sample],
                                  c_PrimSoil = db_pest_e4$c_PrimSoil[n_origin_sample],
                                  c_PrimOffField = db_pest_e4$c_PrimOffField[n_origin_sample],
                                  c_PrimCrop = db_pest_e4$c_PrimCrop[n_origin_sample]
  )
  
  db_pest_e5
})


db_pest_e6 <- db_pest_e5 %>% 
  inner_join(dplyr::select(db_pest2,Id_holding_yr,Type_of_crop,Id_holding,Active_substance,Consumption,(CF_Hc_air_mp:CF_ET_a_soil_mp))) %>% 
  inner_join(db_pest_e2) %>% 
  mutate(
    par_agri_soil = Agri_surface/Total_surface,
    par_surface_fw = Freshwater_surface/Total_surface,
    par_natural_soil = 1-((Agri_surface/Total_surface)- (Freshwater_surface/Total_surface))
  )


db_pest_e7 <- db_pest_e6 %>% 
  mutate(emissions_to_air = c_PrimAir*Consumption,
         emissions_to_agri_soil = (c_PrimSoil+(c_PrimOffField*par_agri_soil))*Consumption,
         emissions_to_natural_soil = c_PrimOffField*par_natural_soil*Consumption,
         emissions_to_freshwater = c_PrimOffField*par_surface_fw*Consumption,
         emissions_to_crop = c_PrimCrop*Consumption) %>%
  dplyr::select(Type_of_crop,Id_holding,(n_origin_sample:Year),(Active_substance:CF_ET_a_soil_mp),(emissions_to_air:emissions_to_crop))
  



# Impacts from pesticide emissions ------------------------------------------------------
## Toxicity impacts from on-field pesticide emissions are assessed using both USEtox and ReCiPe methodologies 


## USEtox

i_pest_e1 <- db_pest_e7 %>% 
  mutate(
    HTc = (emissions_to_air*ifelse(is.na(CF_Hc_air_mp),0,CF_Hc_air_mp))+
      (emissions_to_agri_soil*ifelse(is.na(CF_Hc_a_soil_mp),0,CF_Hc_a_soil_mp))+
      (emissions_to_natural_soil*ifelse(is.na(CF_Hc_n_soil_mp),0,CF_Hc_n_soil_mp))+
      (emissions_to_freshwater*ifelse(is.na(CF_Hc_fw_mp),0,CF_Hc_fw_mp)),
    
    HTnc = (emissions_to_air*ifelse(is.na(CF_Hnc_air_mp),0,CF_Hnc_air_mp))+
      (emissions_to_agri_soil*ifelse(is.na(CF_Hnc_a_soil_mp),0,CF_Hnc_a_soil_mp))+
      (emissions_to_natural_soil*ifelse(is.na(CF_Hnc_n_soil_mp),0,CF_Hnc_n_soil_mp))+
      (emissions_to_freshwater*ifelse(is.na(CF_Hnc_fw_mp),0,CF_Hnc_fw_mp)),
    
    ET = (emissions_to_air*ifelse(is.na(CF_ET_air_mp),0,CF_ET_air_mp))+
      (emissions_to_agri_soil*ifelse(is.na(CF_ET_a_soil_mp),0,CF_ET_a_soil_mp))+
      (emissions_to_natural_soil*ifelse(is.na(CF_ET_n_soil_mp),0,CF_ET_n_soil_mp))+
      (emissions_to_freshwater*ifelse(is.na(CF_ET_fw_mp),0,CF_ET_fw_mp))
  )

i_pest_e1 <- i_pest_e1 %>% 
  group_by(Id_sample,Id_holding_yr,Id_holding) %>% 
  summarise(HTc = sum(HTc),
            HTnc = sum(HTnc),
            ET = sum(ET))

i_pest_e1 <- i_pest_e1 %>% 
  gather(HTc,HTnc,ET,key = 'Acronym',value = 'Impact') %>% 
  mutate(Methodology = Methodology_l[7]) %>% 
  mutate_at(vars(Acronym,Methodology),as_factor) %>% 
  left_join(db_unit_impact2) %>% 
  select(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Unit,Impact)



##  ReCiPe
i_pest_e2 <- spread(db_pest_e3,Compartment,CF) %>% 
  right_join(select(db_pest_e7,(Id_sample:Consumption),(emissions_to_air:emissions_to_freshwater))) %>% 
  mutate(Impact = (emissions_to_agri_soil*agricultural_soil)+(emissions_to_natural_soil*industrial_soil)+(emissions_to_freshwater*freshwater)+(emissions_to_air*rural_air)) %>% 
  filter(!is.na(Impact)) %>% 
  group_by(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Time_perspective,Unit) %>% 
  summarise(Impact = sum(Impact))

i_pest_e2 <- i_pest_e2 %>% 
  filter(Time_perspective == 'H') 

i_pest_e2$Time_perspective <- NULL

i_onfield2 <- union(i_pest_e1,i_pest_e2)


# Total impacts from on-field operations ----------------------------------
## Impacts from on-field emissions from fertiliser are linked to the ones from on-field pesticide emissions 

i_onfield <- union(i_onfield1,i_pest_e2)

i_onfield$Id_sample <- as.factor(i_onfield$Id_sample)
i_onfield$Id_holding_yr <- as.factor(i_onfield$Id_holding_yr)
i_onfield$Methodology <- as.factor(i_onfield$Methodology)
i_onfield$Impact_category <- as.factor(i_onfield$Impact_category)
i_onfield$Acronym <- as.factor(i_onfield$Acronym)
#i_onfield$Time_perspective <- as.factor(i_onfield$Time_perspective)
i_onfield$Unit <- as.factor(i_onfield$Unit)


## The following line can be used to save the impacts estimated from on-field emissions stage as feather file
#write_feather(i_onfield,'iar_onfield_EF_f')



 
