

# Raw data reading ---------------------------------------------------------------

db_machi1 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi13_fuel_for_machinery.xlsx'))%>% 
  mutate_at(vars(NUTS2,NUTS2_ac,Month,Year),as_factor)

# Estimation of diesel consumption -------------------------------------------

db_machi2 <- db_machi1 %>% 
  filter(NUTS2_ac!='ES')%>% 
  group_by(NUTS2,NUTS2_ac,Year)%>% 
  summarise(
    Price_mean = mean(Price),
    para = sd(Price)/mean(Price),
    Price_li = quantile(Price,0.025),
    Price_ls = quantile(Price,0.975)
  )%>% 
  right_join(dplyr::select(db_ecrea,Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,NUTS2_ac,Year,Yield,Fuel_and_lubricant_cost))

set.seed(2022)

db_machi3 <- map_df(.x = 1:nrow(db_machi2),.f = function(x){
  
  db_machi3 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = db_machi2$Id_holding_yr[x],
    Type_of_crop = db_machi2$Type_of_crop[x],
    Id_holding = db_machi2$Id_holding[x],
    Crop = db_machi2$Crop[x],
    System = db_machi2$System[x],
    NUTS2 = db_machi2$NUTS2[x],
    Year = db_machi2$Year[x],
    Diesel_consumption = ((db_machi2$Fuel_and_lubricant_cost[x]/runif(n = n_simulations,min = db_machi2$Price_li[x],max = db_machi2$Price_ls[x]))/db_machi2$Yield[x])*Diesel_density,
    Process = 'Machinery_use'
  )
  db_machi3
}
)


# Impacts from Machinery use ----------------------------------------------
## unit process impacts data frame is linked to db_machi3 and impacts from machinery use are estimated

i_machi <- db_machi3 %>% 
  left_join(db_unit_impact1) %>% 
  mutate(Impact = Diesel_consumption*Unit_impact) %>%
  dplyr::select(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Time_perspective,Unit,Impact)

## The following line can be used to save the impacts estimated from machinery use (diesel) stage as feather file
#write_feather(i_machi,'iar_machinery_f')

