# Raw data reading ------------------------------------------------------------

## Input files to estimate energy consumption

db_power_irri1 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi14_surface_irrigated.xlsx')) %>% 
  mutate_at(vars(NUTS2,Year),as.factor)

db_power_irri2 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi15_water_source_and_use.xlsx')) %>% 
  mutate_at(vars(NUTS2,Year),as.factor)


## Input files to estimate water requirement 

db_water_irri1 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi16_ECREA_sample.xlsx')) 

db_water_irri2 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi17_NUTS.xlsx')) %>% 
  mutate_at(vars(NUTS2,NUTS3),as_factor)

db_water_irri3 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi18_water_irri1.xlsx')) %>% 
  mutate_at(vars(NUTS2,Crop,System),as_factor)

db_water_irri4 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi19_water_irri2_soil.xlsx')) %>% 
  mutate_at(vars(NUTS3,Texture),as_factor)


db_water_irri5 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi20_water_irri3_ETo.xlsx')) %>% 
  mutate_at(vars(NUTS2,NUTS3,Year,Month),as_factor)

db_water_irri6 <- read.xlsx(xlsxFile = file.path(InputData_path,'Dbi21_water_irri4_Kc.xlsx')) %>% 
  mutate_at(vars(Crop),as_factor)



# Energy estimation ------------------------------------------------------

## Input parameters

kwh_m3_desalinated <- 3.9 # energy to desalinate 1 m3 of water (Espinosa-Tasón et al., 2020)
kwh_m3_reclaimed <- 1.17 # energy to reclaim 1 m3 of water (Espinosa-Tasón et al., 2020)
e_conveyance <- c(.85,.95,.9) # water conveyance efficiency (Espinosa-Tasón et al., 2020)
e_distribution <- c(.85,.95,.9) # distribution efficiency (Espinosa-Tasón et al., 2020)
e_diesel_motor <- c(.35,.45,.4) # diesel motor efficiency (Daccache et al., 2014)
e_electric_motor <- c(.85,.95,.9) # electric motor efficiency (Daccache et al., 2014)
e_pump <- c(.75,.85,.8) # pump efficiency (Daccache et al., 2014)
e_furrow <- c(.5,.75,.6) # furrow system efficiency (Berbel et al., 2018; Daccache et al., 2014; Espinosa-Tasón et al., 2020; Phocaides, 2007)
e_sprinkler <- c(.6,.85,.8) # sprinkler system efficiency (Berbel et al., 2018; Daccache et al., 2014; Espinosa-Tasón et al., 2020; Phocaides, 2007)
e_drip <- c(.8,.95,.9) # drip system efficiency (Berbel et al., 2018; Daccache et al., 2014; Espinosa-Tasón et al., 2020; Phocaides, 2007)
losses_pressure <- c(.1,.3,.2) # pressure losses from friction in the irrigation system (Daccache et al., 2014) and personal recommendation 
Gravity_energy <- 5 # gravity energy (m) (Espinosa-Tasón et al., 2020)
o_pressure_furrow <- 0 # operative pressure in furrow system (m)(Espinosa-Tasón et al., 2020)
o_pressure_sprinkler <- 30.59 # operative pressure in sprinkler system (m) (Espinosa-Tasón et al., 2020)
o_pressure_drip <- 10.2 # operative pressure in drip system (m) (Espinosa-Tasón et al., 2020)
p_pump_furrow <- o_pressure_furrow*(1+losses_pressure) # Pump pressure in furrow system (m)
p_pump_sprinkler <- o_pressure_sprinkler*(1+losses_pressure)# Pump pressure in sprinkler system (m)
p_pum_drip <- o_pressure_drip*(1+losses_pressure)# Pump pressure in drip system (m)
elev_surface_water_source <- 5 #Pumping lift for surface water (m) (Espinosa-Tasón et al., 2020)
elev_groundwater_source <- c(20,80,60) #Pumping lift for groundwater (Espinosa-Tasón et al., 2020)




## Number of diesel and electric motors for irrigation (Espinosa-Tasón et al., 2020)
db_power_irri3 <- tibble(Year = c(2010,2011,2012,2013,2014,2015,2016,2017),
                     Diesel_porc = c(.21,.18,.15,.12,.1,.1,.05,.05),
                     Electric_porc = c(.79,.82,.85,.88,.9,.9,.95,.95)
) %>% 
  mutate_at(vars(Year),as.factor)


## percentage of desalinated and reclaimed water for irrigation (Espinosa-Tasón et al., 2020)
db_power_irri4 <- tibble(Year = c(2010,2011,2012,2013,2014,2015,2016,2017),
                            Desalinated_hm3 = c(13.16,17.28,19.02,37.47,47.3,79.56,125.64,141.5),
                            Reclaimed_hm3 = c(195.55,252.979,293.07,296.277,324.839,259.907,222.288,220)
) %>% 
  mutate_at(vars(Year),as.factor)


db_power_irri4 <- db_power_irri4 %>%
  transmute(
    Year = Year,
    Weight_desalinated_water = Desalinated_hm3/(Desalinated_hm3+Reclaimed_hm3),
    Weight_reclaimed_water = Reclaimed_hm3/(Desalinated_hm3+Reclaimed_hm3)
  )



# Estimation of energy consumption for irrigation (kWh/m3 of irrigation water) ---------------------------------


db_power_irri5 <- db_power_irri2 %>%
  left_join(db_power_irri1) %>% 
  left_join(db_power_irri4) %>% 
  left_join(db_power_irri3)

db_power_irri6 <- dplyr::select(db_ecrea,Year,NUTS2,Id_holding_yr,Type_of_crop,Id_holding) %>% 
  left_join(db_power_irri5) 



set.seed(2022)
db_power_irri7 <- map_df(.x = 1:nrow(db_power_irri6),.f = function(x){
  db_power_irri7 <- tibble(Id_sample = c(1:n_simulations),
                         Id_holding_yr = db_power_irri6$Id_holding_yr[x],
                         Type_of_crop = db_power_irri6$Type_of_crop[x],
                         Id_holding = db_power_irri6$Id_holding[x],
                         Diesel_motor_rate = db_power_irri6$Diesel_porc[x],
                         Electric_motor_rate = db_power_irri6$Electric_porc[x],
                         e_global_pump = ((db_power_irri6$Diesel_porc[x]*rtriangle(n_simulations,e_diesel_motor[1],e_diesel_motor[2],e_diesel_motor[3]))+
                                            (db_power_irri6$Electric_porc[x]*rtriangle(n_simulations,e_electric_motor[1],e_electric_motor[2],e_electric_motor[3])))*
                           rtriangle(n_simulations,e_pump[1],e_pump[2],e_pump[3]),
                         e_app = ((db_power_irri6$Furrow_irrigated_surface[x]*rtriangle(n_simulations,e_furrow[1],e_furrow[2],e_furrow[3]))+
                                    (db_power_irri6$Sprinkler_irrigated_surface[x]*rtriangle(n_simulations,e_sprinkler[1],e_sprinkler[2],e_sprinkler[3]))+
                                    (db_power_irri6$Drip_irrigated_surface[x]*rtriangle(n_simulations,e_drip[1],e_drip[2],e_drip[3])))/db_power_irri6$Total_surface_irrigated_FSD[x],
                         
                         e_conv_dist = e_app*rtriangle(n_simulations,e_conveyance[1],e_conveyance[2],e_conveyance[3])*
                           rtriangle(n_simulations,e_distribution[1],e_distribution[2],e_distribution[3]), 
                         
                         e_system = ((db_power_irri6$Surface_water_source[x]/(db_power_irri6$Surface_water_source[x]+db_power_irri6$Groundwater_source[x]))*e_conv_dist)+
                           ((db_power_irri6$Groundwater_source[x]/(db_power_irri6$Surface_water_source[x]+db_power_irri6$Groundwater_source[x]))*e_app),
                         
                         p_md_pump = ((db_power_irri6$Surface_water_source[x]/(db_power_irri6$Surface_water_source[x]+db_power_irri6$Groundwater_source[x]))*elev_surface_water_source)+
                           ((db_power_irri6$Groundwater_source[x]/(db_power_irri6$Surface_water_source[x]+db_power_irri6$Groundwater_source[x]))*rtriangle(n_simulations,elev_groundwater_source[1],elev_groundwater_source[2],elev_groundwater_source[3])),
                         
                         p_furrow_total = (o_pressure_furrow*(1+rtriangle(n_simulations,losses_pressure[1],losses_pressure[2],losses_pressure[3]))) + Gravity_energy,
                         p_sprinkler_total = (o_pressure_sprinkler*(1+rtriangle(n_simulations,losses_pressure[1],losses_pressure[2],losses_pressure[3]))) + p_md_pump,
                         p_drip_total = (o_pressure_drip*(1+rtriangle(n_simulations,losses_pressure[1],losses_pressure[2],losses_pressure[3]))) + p_md_pump,
                         #Power for different systems and for desalinated and reclaimed water (kWh·m3 of water)
                         Power_for_furrow_system = p_furrow_total/(367*e_global_pump),
                         Power_for_sprinkler_system = p_sprinkler_total/(367*e_global_pump),
                         Power_for_drip_system = p_drip_total/(367*e_global_pump),
                         Power_for_des_and_rec_water = (kwh_m3_desalinated*db_power_irri6$Weight_desalinated_water[x])+
                           (kwh_m3_reclaimed*db_power_irri6$Weight_reclaimed_water[x]),
                         Power_for_irrigation = (((Power_for_furrow_system*db_power_irri6$Furrow_water_used[x])+
                                                    (Power_for_sprinkler_system*db_power_irri6$Sprinkler_water_used[x])+
                                                    (Power_for_drip_system*db_power_irri6$Drip_water_used[x]))/db_power_irri6$Total_water_type_irrigation[x])+(Power_for_des_and_rec_water*(db_power_irri6$Other_water_source[x]/db_power_irri6$Total_water_source[x]))
  )
  
  db_power_irri7 %>% 
    dplyr::select(Id_sample,Type_of_crop,Id_holding,Id_holding_yr,e_system,Electric_motor_rate,Diesel_motor_rate,(Power_for_furrow_system:Power_for_irrigation))
})




# Estimation of irrigation water requirement -----------------------------------------------------

## Calculation of NUTS 3 participation in the ECREAs samples

db_water_irri7 <- db_water_irri1 %>% 
  gather(Almeria,Cadiz,Cordoba,Granada,Huelva,Sevilla,Jaen,Malaga,Huesca,Teruel,Zaragoza,Ciudad_Real,Cuenca,Toledo,Avila,Burgos,Palencia,
         Salamanca,Valladollid,Zamora,Barcelona,Tarragona,Gerona,Lerida,Alicante,Castellon,Valencia,Badajoz,Caceres,Murcia,Logrono,key = 'NUTS3',value = 'ecrea_sample') %>% 
  filter(!is.na(ecrea_sample)) %>% 
  mutate_at(vars(Type_of_crop,Crop,System,Year,NUTS3),as_factor) %>%
  left_join(db_water_irri2) 
  

db_water_irri7 <- dplyr::select(db_ecrea, Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year,Number_of_holdings_sampled,Yield) %>% 
  left_join(db_water_irri7) %>% 
  group_by(Crop,System,NUTS2,Year) %>% 
  mutate(sample_test = ifelse(sum(ecrea_sample)== Number_of_holdings_sampled,0,1),
         sample_rate = ecrea_sample/sum(ecrea_sample)
  )


## statistics of ETo and precipitation

db_water_irri8 <- db_water_irri5 %>% 
  group_by(NUTS2,NUTS3,Year,Month) %>% 
  summarise(ETo_md = mean(ETo_mm,na.rm = T),
            ETo_sd = sd(ETo_mm,na.rm = T),
            ETo_ll = quantile(ETo_mm,.025,na.rm = T),
            ETo_ul = quantile(ETo_mm,.975,na.rm = T),
            Pe_md = mean(Pe_mm,na.rm = T),
            Pe_sd = sd(Pe_mm,na.rm = T),
            Pe_ll = quantile(Pe_mm,.025,na.rm = T),
            Pe_ul = quantile(Pe_mm,.975,na.rm = T)
            )

# ETo and precipitation data are linked to the reference holdings

db_water_irri9 <- db_water_irri7 %>% 
  left_join(db_water_irri8)

db_water_irri10 <- db_water_irri9 %>% 
  group_by(Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,NUTS3,Year,Month) %>% 
  transmute(Yield = Yield,
            ETo_md = ETo_md*sample_rate,
            ETo_sd = ETo_sd*sample_rate,
            ETo_ll = ETo_ll*sample_rate,
            ETo_ul = ETo_ul*sample_rate,
            Pe_md = Pe_md*sample_rate,
            Pe_sd = Pe_sd*sample_rate,
            Pe_ll = Pe_ll*sample_rate,
            Pe_ul = Pe_ul*sample_rate
  )


# Weight allocation of the ETo and precipitation statistics is developed according to NUTS 3 representation in the ECREAs samples  

db_water_irri10 <- db_water_irri10 %>% 
  group_by(Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year,Month) %>% 
  summarise(Yield = mean(Yield),
            ETo_md = sum(ETo_md),
            ETo_sd = sum(ETo_sd),
            ETo_ll = sum(ETo_ll),
            ETo_ul = sum(ETo_ul),
            Pe_md = sum(Pe_md),
            Pe_sd = sum(Pe_sd),
            Pe_ll = sum(Pe_ll),
            Pe_ul = sum(Pe_ul)
  )



## Kc statistics. the Kc recommended value is estimated as weighted average according to the repetition of the Kc scores in the raw data

db_water_irri11 <- db_water_irri6 %>% 
  group_by(Crop) %>% 
  mutate(
    Kc_mdp =Kc*(Repetitions/sum(Repetitions))
  ) %>% 
  summarise(Kc_mdp = sum(Kc_mdp),
            Kc_sd = sd(Kc),
            Kc_ll = quantile(Kc,.025),
            Kc_ul = quantile(Kc,.975)
            )


## Statistics for water soil availability. The recommended value is estimated as weighted average according to the repetition of the type of soil in each NUTS 2

db_water_irri12 <- db_water_irri4 %>% 
  group_by(NUTS2) %>% 
  summarise(FC_WP_sd = sd(Available_water),
            FC_WP_ll = quantile(Available_water,.025),
            FC_WP_ul = quantile(Available_water,.975),
            n = n())


db_water_irri13 <- db_water_irri4 %>% 
  group_by(NUTS2,Texture) %>% 
  summarise(FC_WP_md = mean(Available_water),
            n = n()) %>% 
  mutate(
    FC_WP_mdp1 = FC_WP_md*(n/sum(n))
  )


db_water_irri13 <- db_water_irri13 %>% 
  group_by(NUTS2) %>% 
  summarise(
    FC_WP_mdp = sum(FC_WP_mdp1)
  )


db_water_irri14 <- db_water_irri13 %>% 
  inner_join(db_water_irri12)

## db_water_irri14 is linked to crops season data

db_water_irri15 <- db_water_irri3 %>% 
  left_join(db_water_irri14)

## season months are reorganized vertically.  

db_water_irri15 <- db_water_irri15 %>% 
  gather(`January`,`February`,`March`,`April`,`May`,`June`,`July`,
         `August`,`September`,`October`,`November`,`December`,
         key = 'Month',value = 'Dichotomic_month')


## Parameters to estimated water irrigation are linked in the same data frame 

db_water_irri16 <- db_water_irri15 %>% 
  right_join(db_water_irri10) %>% 
  filter(Dichotomic_month==1)


db_water_irri17 <- db_water_irri16 %>% 
  left_join(db_water_irri11, by = 'Crop')%>%   
  filter(System !='Rainfed open field')



# Simulation of ETo and precipitation scores. Unit values for available soil water in the root zone (RAW) and Kc for each reference holding per year are calculated.


set.seed(2022)
db_water_irri18 <- map_df(.x = 1:nrow(db_water_irri17),.f = function (x){
 
  db_water_irri18 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = db_water_irri17$Id_holding_yr[x],
    Type_of_crop = db_water_irri17$Type_of_crop[x],
    Id_holding = db_water_irri17$Id_holding[x],
    Id_group = paste(Id_holding_yr,Id_sample,sep = '_'),
    Crop = db_water_irri17$Crop[x],
    System = db_water_irri17$System[x],
    NUTS2 = db_water_irri17$NUTS2[x],
    Year = db_water_irri17$Year[x],
    Yield = db_water_irri17$Yield[x],
    Month = db_water_irri17$Month[x],
    ETo = rtriangle(n_simulations,db_water_irri17$ETo_ll[x],db_water_irri17$ETo_ul[x],db_water_irri17$ETo_md[x]),
    Pe = rtriangle(n_simulations,db_water_irri17$Pe_ll[x],db_water_irri17$Pe_ul[x],db_water_irri17$Pe_md[x])
                )
  
  db_water_irri18
  
})


db_water_irri19 <- db_water_irri17 %>% 
  group_by(Id_holding_yr,Type_of_crop,Id_holding) %>% 
  summarise(
    Kc_mdp = mean(Kc_mdp),
    Kc_ll = mean(Kc_ll),
    Kc_ul = mean(Kc_ul),
    Rooting_depth_ll = mean(Rooting_depth_ll),
    Rooting_depth_ul = mean(Rooting_depth_ul),
    FC_WP_mdp = mean(FC_WP_mdp),
    FC_WP_ll = mean(FC_WP_ll),
    FC_WP_ul = mean(FC_WP_ul),
    Depletion_fraction = mean(Depletion_fraction)
  )

set.seed(2022)

db_water_irri20 <- map_df(.x = 1:nrow(db_water_irri19),.f = function (x){
  
  db_water_irri20 <- tibble(
    Id_sample = c(1:n_simulations),
    Id_holding_yr = db_water_irri19$Id_holding_yr[x],
    Type_of_crop = db_water_irri19$Type_of_crop[x],
    Id_holding = db_water_irri19$Id_holding[x],
    Kc = rtriangle(n_simulations,db_water_irri19$Kc_ll[x],db_water_irri19$Kc_ul[x],db_water_irri19$Kc_mdp[x]),
    Zr = runif(n_simulations,db_water_irri19$Rooting_depth_ll[x],db_water_irri19$Rooting_depth_ul[x]),
    FC_WP = rtriangle(n_simulations,db_water_irri19$FC_WP_ll[x],db_water_irri19$FC_WP_ul[x],db_water_irri19$FC_WP_mdp[x]),
    TAW = FC_WP*Zr*1000,# 1000 is used to change m to mm 
    p = db_water_irri19$Depletion_fraction[x],
    RAW = TAW*p
   )
  
  db_water_irri20
  
})


db_water_irri21 <- db_water_irri18 %>% 
  inner_join(db_water_irri20) %>% 
  mutate(ETc = ETo*Kc)
  
## Only the precipitation > 20% of ETo is considered as useful to feed the soil with water
  

db_water_irri22 <- db_water_irri21 %>% 
  mutate(
    P_RO = case_when(
      is.na(Pe) ~ 0,
      System == 'Irrigated greenhouse'~ 0,
      Pe < 0.2*ETo ~ 0,
      Pe >= 0.2*ETo ~ Pe
    ),
    DP = 0,
    I = 0,
    Dr = 0
  ) 

# Data is tidied to apply iteration and to estimate the water irrigation requiriments

dbw <-  db_water_irri22 %>% 
  arrange(Id_group)%>% 
group_by(Id_group) %>% 
  mutate(
    Id_month = row_number()
    )

dbw <- dbw %>% 
  group_by(Id_sample,Id_holding_yr,Id_group) %>% 
  mutate(n = n())


dbw$Last <- ifelse(dbw$Id_month==dbw$n,1,0)

## Iterations are applied

## Iteration 1

dbw$DP <- ifelse(dbw$Id_month==1,dbw$P_RO,dbw$DP)

dbw$Dr <- ifelse(dbw$Id_month==1,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I,dbw$Dr)




## Iteration 2

dbw$DP <- ifelse(dbw$Id_month==2 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==2 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==2 & lag(dbw$Dr) < lag(dbw$RAW),0,
                ifelse(dbw$Id_month==2 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                       ifelse(dbw$Id_month==2 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                              lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I)))


dbw$Dr <- ifelse(dbw$Id_month==2,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr)



## Iteration 3

dbw$DP <- ifelse(dbw$Id_month==3 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==3 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==3 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==3 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==3 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==3 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==3 & dbw$Last == 1, 0,ifelse(dbw$Id_month==3 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))


## Iteration 4

dbw$DP <- ifelse(dbw$Id_month==4 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==4 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))


dbw$I <- ifelse(dbw$Id_month==4 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==4 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==4 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==4 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))



dbw$Dr <- ifelse(dbw$Id_month==4 & dbw$Last == 1, 0,ifelse(dbw$Id_month==4 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 5

dbw$DP <- ifelse(dbw$Id_month==5 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==5 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))


dbw$I <- ifelse(dbw$Id_month==5 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==5 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==5 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==5 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))

dbw$Dr <- ifelse(dbw$Id_month==5 & dbw$Last == 1, 0,ifelse(dbw$Id_month==5 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 6

dbw$DP <- ifelse(dbw$Id_month==6 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==6 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==6 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==6 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==6 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==6 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==6 & dbw$Last == 1, 0,ifelse(dbw$Id_month==6 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 7

dbw$DP <- ifelse(dbw$Id_month==7 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==7 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==7 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==7 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==7 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==7 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==7 & dbw$Last == 1, 0,ifelse(dbw$Id_month==7 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 8

dbw$DP <- ifelse(dbw$Id_month==8 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==8 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))


dbw$I <- ifelse(dbw$Id_month==8 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==8 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==8 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==8 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))

dbw$Dr <- ifelse(dbw$Id_month==8 & dbw$Last == 1, 0,ifelse(dbw$Id_month==8 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))


## iteration 9

dbw$DP <- ifelse(dbw$Id_month==9 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==9 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==9 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==9 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                         ifelse(dbw$Id_month==9 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                ifelse(dbw$Id_month==9 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                       lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==9 & dbw$Last == 1, 0,ifelse(dbw$Id_month==9 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 10

dbw$DP <- ifelse(dbw$Id_month==10 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==10 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==10 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==10 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                          ifelse(dbw$Id_month==10 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                 ifelse(dbw$Id_month==10 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                        lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==10 & dbw$Last == 1, 0,ifelse(dbw$Id_month==10 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))




## iteration 11

dbw$DP <- ifelse(dbw$Id_month==11 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==11 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==11 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==11 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                          ifelse(dbw$Id_month==11 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                 ifelse(dbw$Id_month==11 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                        lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==11 & dbw$Last == 1, 0,ifelse(dbw$Id_month==11 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))



## iteration 12

dbw$DP <- ifelse(dbw$Id_month==12 & dbw$P_RO <= lag(dbw$Dr),0,
                 ifelse(dbw$Id_month==12 & dbw$P_RO > lag(dbw$Dr),dbw$P_RO-lag(dbw$Dr),dbw$DP))

dbw$I <- ifelse(dbw$Id_month==12 & dbw$Last == 1,lag(dbw$Dr)+dbw$ETc-dbw$P_RO+dbw$DP,ifelse(dbw$Id_month==12 & lag(dbw$Dr) < lag(dbw$RAW),0,
                                                                                          ifelse(dbw$Id_month==12 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO >= lag(dbw$Dr),0,
                                                                                                 ifelse(dbw$Id_month==12 & lag(dbw$Dr) >= lag(dbw$RAW)& dbw$P_RO < lag(dbw$Dr),
                                                                                                        lag(dbw$Dr)-dbw$P_RO+dbw$DP,dbw$I))))


dbw$Dr <- ifelse(dbw$Id_month==12 & dbw$Last == 1, 0,ifelse(dbw$Id_month==12 & dbw$Last == 0,dbw$ETc-dbw$P_RO+dbw$DP-dbw$I+lag(dbw$Dr),dbw$Dr))


## Net irrigation water requirements

db_water_irr23 <- dbw %>% 
  group_by(Id_sample,Id_holding_yr,Type_of_crop,Id_holding,Crop,System,NUTS2,Year) %>% 
  summarise(
    ETo = sum(ETo), 
    ETc = sum (ETc),
    Pe = sum (Pe, na.rm = T),
    P_RO = sum (P_RO),
    I_net = (sum(I)*10)/mean(Yield),# 10 is the factor to change water consumption from mm to m3·ha-1
    Dr = last (Dr),
    n = mean(n)
  )



##  Water and energy consumption from irrigation

db_water_irr24 <- db_water_irr23 %>% 
 left_join(db_power_irri7) %>% 
  mutate(
    I_gross = I_net/e_system,
    Water_consumption = (ETc/ETo)*I_net,
    Power_for_irrigation_total = (I_net/e_system)*Power_for_irrigation,
    Power_from_electric_pump = (I_net/e_system)*Power_for_irrigation*Electric_motor_rate,
    Power_from_diesel_pump = (I_net/e_system)*Power_for_irrigation*Diesel_motor_rate
  )


# Impacts from irrigation -------------------------------------------------
## unit process impacts data frame is linked to db_water_irri24 and impacts from irrigation are estimated

i_irrigation1 <- db_water_irr24 %>%
  rename(Electric_pump = Power_from_electric_pump,
         Diesel_pump = Power_from_diesel_pump
         ) %>% 
  select(Id_sample,Id_holding_yr,Electric_pump,Diesel_pump) %>% 
  gather(Electric_pump,Diesel_pump,key = 'Process',value = 'Consumption')


i_irrigation2 <- db_water_irr24 %>% 
  rename(Consumption = Water_consumption) %>%
  mutate(Process = NUTS2) %>% 
  select(Id_sample,Id_holding_yr,Process,Consumption) %>% 
  full_join(i_irrigation1) %>% 
  mutate_at(vars(Id_sample,Id_holding_yr,Process),as_factor)
  
i_irrigation3 <- i_irrigation2 %>% 
  left_join(db_unit_impact1) %>% 
  mutate(Impact = Consumption*Unit_impact) %>% 
  group_by(Id_sample,Id_holding_yr,Methodology,Impact_category,Acronym,Unit) %>% 
  summarise(Impact = sum(Impact))


## The following line can be used to save the impacts estimated from irrigation stage as feather file
#write_feather(i_irrigation3,'iar_irrigation_EF_f')


